unit TestMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, SlyIrc, ComCtrls;

type
  TfrmMain = class(TForm)
    pnlButtons: TPanel;
    edtHost: TEdit;
    edtPort: TEdit;
    edtNick: TEdit;
    edtAltNick: TEdit;
    lblHost: TLabel;
    lblPort: TLabel;
    lblNicks: TLabel;
    btnConnect: TButton;
    btnQuit: TButton;
    sbrMain: TStatusBar;
    pnlStatus: TPanel;
    memStatus: TMemo;
    edtUsername: TEdit;
    lblUsername: TLabel;
    chkShowTokens: TCheckBox;
    pnlCommand: TPanel;
    edtCommand: TEdit;
    chkInvisible: TCheckBox;
    chkServerNotices: TCheckBox;
    chkWallops: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnConnectClick(Sender: TObject);
    procedure btnQuitClick(Sender: TObject);
    procedure edtCommandKeyPress(Sender: TObject; var Key: Char);
    procedure chkInvisibleClick(Sender: TObject);
    procedure chkServerNoticesClick(Sender: TObject);
    procedure chkWallopsClick(Sender: TObject);
  private
    FSlyIrc: TSlyIrc;
    procedure SlyIrcReceive(Sender: TObject; AResponse: String);
    procedure SlyIrcSend(Sender: TObject; AResponse: String);
    procedure SlyIrcAfterStateChange(Sender: TObject);
    procedure SlyIrcResponse(Sender: TObject; ATokens: TIrcToken;
      var Suppress: Boolean);
    procedure SlyIrcUserModeChanged(Sender: TObject);
  public
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}

const
  StateDesc: array [TSlyIrcState] of String = ('Not connected', 'Resolving host', 'Connecting', 'Connected',
    'Registering', 'Ready', 'Aborting', 'Disconnecting');

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  FSlyIrc := TSlyIrc.Create(nil);
  FSlyIrc.OnReceive := SlyIrcReceive;
  FSlyIrc.OnSend := SlyIrcSend;
  FSlyIrc.OnAfterStateChange := SlyIrcAfterStateChange;
  FSlyIrc.OnResponse := SlyIrcResponse;
  FSlyIrc.OnUserModeChanged := SlyIrcUserModeChanged;
end;

procedure TfrmMain.FormDestroy(Sender: TObject);
begin
  FSlyIrc.Free;
end;

procedure TfrmMain.btnConnectClick(Sender: TObject);
begin
  FSlyIrc.Host := edtHost.Text;
  FSlyIrc.Port := edtPort.Text;
  FSlyIrc.Nick := edtNick.Text;
  FSlyIrc.AltNick := edtAltNick.Text;
  FSlyIrc.Username := edtUsername.Text;
  FSlyIrc.Connect;
end;

procedure TfrmMain.btnQuitClick(Sender: TObject);
begin
  FSlyIrc.Quit('Bye bye');
end;

procedure TfrmMain.SlyIrcReceive(Sender: TObject; AResponse: String);
begin
  memStatus.Lines.Add('>> ' + AResponse);
end;

procedure TfrmMain.SlyIrcAfterStateChange(Sender: TObject);
begin
  sbrMain.SimpleText := StateDesc[FSlyIrc.State];
  case FSlyIrc.State of
    isNotConnected:
      begin
        memStatus.Lines.Add('Disconnected');
        Caption := 'TestIRC';
      end;
    isResolvingHost:
      memStatus.Lines.Add('Resolving host');
    isConnecting:
      memStatus.Lines.Add('Connecting to host');
    isConnected:
      memStatus.Lines.Add('Connected to host');
    isRegistering:
      memStatus.Lines.Add('Registering');
    isReady:
      Caption := Format('%s on %s - TestIRC', [FSlyIrc.Nick, FSlyIrc.Host]);
    isAborting:
      memStatus.Lines.Add('Aborting connection');
    isDisconnecting:
      memStatus.Lines.Add('Disconnecting');
  end;
end;

procedure TfrmMain.SlyIrcSend(Sender: TObject; AResponse: String);
begin
  memStatus.Lines.Add('<< ' + AResponse);
end;

procedure TfrmMain.SlyIrcResponse(Sender: TObject; ATokens: TIrcToken;
  var Suppress: Boolean);
var
  Line: String;
  Index: Integer;
begin
  if chkShowTokens.Checked then
  begin
    Line := '"' + ATokens[0] + '"';
    for Index := 1 to ATokens.Count - 1 do
      Line := Line + ', "' + ATokens[Index] + '"';
    memStatus.Lines.Add(Line);
  end;
end;

procedure TfrmMain.edtCommandKeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #13 then
  begin
    { Suppress beep. }
    Key := #0;
    FSlyIrc.Send(edtCommand.Text);
    edtCommand.Text := '';
  end;
end;

procedure TfrmMain.SlyIrcUserModeChanged(Sender: TObject);
begin
  memStatus.Lines.Add('User mode changed');
end;

procedure TfrmMain.chkInvisibleClick(Sender: TObject);
begin
  if chkInvisible.Checked then
    FSlyIrc.UserModes := FSlyIrc.UserModes + [umInvisible]
  else
    FSlyIrc.UserModes := FSlyIrc.UserModes - [umInvisible];
end;

procedure TfrmMain.chkServerNoticesClick(Sender: TObject);
begin
  if chkServerNotices.Checked then
    FSlyIrc.UserModes := FSlyIrc.UserModes + [umServerNotices]
  else
    FSlyIrc.UserModes := FSlyIrc.UserModes - [umServerNotices];
end;

procedure TfrmMain.chkWallopsClick(Sender: TObject);
begin
  if chkWallops.Checked then
    FSlyIrc.UserModes := FSlyIrc.UserModes + [umWallops]
  else
    FSlyIrc.UserModes := FSlyIrc.UserModes - [umWallops];
end;

end.
